<?php
$lang['friendlyname'] = 'Editeur TinyMCE WYSIWYG';
$lang['uninstalled'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute;.';
$lang['installed'] = 'La version %s du module a &eacute;t&eacute; install&eacute;e.';
$lang['stripbackgroundtags'] = 'Lors de l&#039;&eacute;dition, affiche avec le CSS, mais sans le fond&nbsp;';
$lang['stiptags_help'] = 'Cette option tente de supprimer les param&egrave;tres du type background de la feuille de style.';
$lang['source_formatting_text'] = 'Appliquer le formatage de la source &agrave; la vue HTML&nbsp;';
$lang['dropdownblockformats_text'] = 'Formatage dans &quot;Bloc de texte&quot;&nbsp;';
$lang['allowtables'] = 'Autoriser des op&eacute;rations sur les tables&nbsp;';
$lang['newlinestyle_text'] = 'Retour &agrave; la ligne (Touche Entr&eacute;e)&nbsp;';
$lang['pstyle'] = 'style &amp;lt;p&amp;gt;';
$lang['brstyle'] = 'style &amp;lt;br/&amp;gt;';
$lang['usecompressiontext'] = 'Utilise la compression gz&nbsp;';
$lang['usecompressionhelp'] = 'Cela peut acc&eacute;l&eacute;rer la vitesse de chargement de TinyMCE, mais peut aussi ne pas fonctionner avec votre h&eacute;bergement. A utiliser avec pr&eacute;caution.';
$lang['forcedrootblocktext'] = 'Force &quot;< p > rootblock&quot;&nbsp;';
$lang['forcedrootblockhelp'] = 'Force le contenu retourn&eacute; &agrave; &ecirc;tre au moins inclu dans la balise < p >';
$lang['filepickerstyle'] = 'Style de Filepicker&nbsp;';
$lang['filepickersize'] = 'Taille de Filepicker&nbsp;';
$lang['allowuploadtext'] = 'Autoriser l&#039;upload de fichiers et la cr&eacute;ation de dossiers avec FilePicker&nbsp;';
$lang['allowscalingtext'] = 'Permettre le redimensionnement automatique des images t&eacute;l&eacute;charg&eacute;es&nbsp;';
$lang['scalingdimensionstext'] = 'Dimensions par d&eacute;faut&nbsp;';
$lang['resizeto'] = 'Redimensionner &agrave;&nbsp;:';
$lang['makethumbnail'] = 'Faire une vignette lors du t&eacute;l&eacute;chargement d&#039;images&nbsp;';
$lang['useadvancedprofile'] = 'Utiliser les param&egrave;tres avanc&eacute;s du profil TinyMCE';
$lang['saveprofile'] = 'Sauvegarder le profil';
$lang['profilesaved'] = 'Profil sauvegard&eacute;';
$lang['profiles_tab'] = 'Profils';
$lang['advanced_backend_toolbars'] = 'Profil param&egrave;tres avanc&eacute;s (backend)';
$lang['savestyles'] = 'Sauvegarder les styles';
$lang['allowadvancedprofile'] = 'Autoriser l&#039;utilisation des param&egrave;tres avanc&eacute;s dans le profil de TinyMCE';
$lang['showfilemanagement'] = 'Montrer les options sur les fichiers&nbsp;';
$lang['showfilemanagementhelp'] = 'Afficher les options sur les fichiers comme le t&eacute;l&eacute;chargement, cr&eacute;ation de r&eacute;pertoires et suppression des fichiers avec FilePicker, si l&#039;utilisateur est autoris&eacute; &agrave; effectuer ces op&eacute;rations.';
$lang['restrictdirs'] = 'Restreindre l&#039;acc&egrave;s aux dossiers utilisateur&nbsp;';
$lang['restrictdirshelp'] = 'Cela restreint la gestion des fichiers &agrave; un sous-r&eacute;pertoire de &quot;uploads&quot; qui a le m&ecirc;me nom que le login de l&#039;utilisateur. Si le sous-r&eacute;pertoire n&#039;existe pas, il sera peut-&ecirc;tre cr&eacute;&eacute;. S&#039;il vous pla&icirc;t notez que ceci fonctionne pour le moment uniquement avec les dossiers standard, uploads/images. Cela peut changer &agrave; l&#039;avenir.';
$lang['deleteconfirmation'] = '&Ecirc;tes-vous s&ucirc;r(e) que ce fichier doit &ecirc;tre supprim&eacute; ?';
$lang['deletefilesuccess'] = 'supprim&eacute; avec succ&egrave;s';
$lang['deletefilefailed'] = 'n&#039;a pas pu &ecirc;tre supprim&eacute;';
$lang['deletesubdirfailed'] = 'n&#039;a pas pu &ecirc;tre supprim&eacute;';
$lang['deletesubdirsuccess'] = 'a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['deletedirconfirmation'] = '&Ecirc;tes-vous s&ucirc;r(e) que ce sous-dossier vide doit &ecirc;tre supprim&eacute; ?';
$lang['deletedir'] = 'Supprimer un sous-dossier vide';
$lang['deletefile'] = 'Effacer le fichier';
$lang['cannotreadconfig'] = 'Impossible de lire le fichier tinyconfig.php, aussi TinyMCE ne fonctionnera probablement pas. Vous devriez v&eacute;rifier les permissions de ce fichier et des dossiers parents, qui doivent avoir les permissions de lecture pour tous et d&#039;&eacute;criture uniquement pour le propri&eacute;taire.';
$lang['filenameonly'] = 'Afficher les noms des fichiers';
$lang['thumbnailsonly'] = 'Afficher les vignettes';
$lang['showthumbnailfilestext'] = 'Afficher les vignettes images comme des fichiers normaux&nbsp;';
$lang['filenameandthumbnails'] = 'Afficher les vignettes et les noms des fichiers';
$lang['skinstext'] = 'Skin&nbsp;';
$lang['skinvariationtext'] = 'Variation de Skin&nbsp;';
$lang['advancedwarning'] = '<strong>ATTENTION !<br/>Le changement de ces param&egrave;tres peut emp&ecirc;cher TinyMCE de fonctionner ou g&eacute;n&eacute;rer du code non conforme. A utiliser seulement si vous savez ce que vous faites ! Consulter le site WEB de TinyMCE avant de modifier.</strong>';
$lang['entityencoding_text'] = 'Encodage des entit&eacute;s&nbsp;';
$lang['rawencoding'] = 'Encodage Raw (plus rapide, convient dans la plupart des cas)';
$lang['namedencoding'] = 'Encodage caract&egrave;res (comme &amp;amp;nbsp;)';
$lang['numericencoding'] = 'Encodage num&eacute;rique (comme &amp;amp;#160;)';
$lang['show_path_text'] = 'Afficher le d&eacute;tail de l&#039;&eacute;l&eacute;ment en bas de l&#039;&eacute;diteur&nbsp;';
$lang['toolbar_tab'] = 'Barres d&#039;outils';
$lang['toolbar_help'] = 'Ces options doivent &ecirc;tre s&eacute;par&eacute;es par une virgule pour ins&eacute;rer un bouton/contr&ocirc;le dans la barre d&#039;outils. Le caract&egrave;re | peut &ecirc;tre utilis&eacute; en remplacement du mot &#039;separator&#039;';
$lang['toolbar_text'] = 'Barre d&#039;outils';
$lang['toolbarhelptext'] = 'Cliquez ici pour pour voir les instructions de la barre d&#039;outils sur le Wiki de TinyMCE.';
$lang['editor_width_text'] = 'Largeur de l&#039;&eacute;diteur&nbsp;';
$lang['editor_height_text'] = 'Hauteur de l&#039;&eacute;diteur&nbsp;';
$lang['auto'] = 'Auto ';
$lang['or'] = 'ou';
$lang['allowresizing'] = 'Redimensionnement sur pages du site du champ de l&#039;&eacute;diteur ';
$lang['resizenone'] = 'Interdire le redimensionnement';
$lang['resizeboth'] = 'Autoriser le redimensionnement en hauteur et en largeur';
$lang['resizeheight'] = 'Autoriser seulement le redimensionnement de la hauteur';
$lang['datetimeformat_text'] = 'Format Date/Heure&nbsp;';
$lang['timetext'] = 'Heure&nbsp;';
$lang['datetext'] = 'Date&nbsp;';
$lang['datetimeformat_help'] = 'Cliquez ici pour l&#039;aide sur le format Date/Heure';
$lang['extraconfigtext'] = 'Extra configuration&nbsp;';
$lang['extraconfighelp2'] = 'Une d&eacute;claration par ligne, une virgule sera ajout&eacute;e avant et apr&egrave;s ce contenu. Merci de v&eacute;rifier sur le wiki de TinyMCE pour instructions.';
$lang['customdropdowntext'] = 'Dropdown personnalis&eacute;&nbsp;';
$lang['customdropdownhelp'] = 'Ins&egrave;re des fragments de code/texte personnalis&eacute;s par s&eacute;lection dans le menu d&eacute;roulant.  L&#039;utilisation des balises (tags) s&#039;en trouve facilit&eacute;e. Le menu est ins&eacute;r&eacute; dans la barre d&#039;outils en utilisant &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'D&eacute;marrage permis&nbsp;';
$lang['startenabledhelp'] = 'D&eacute;cocher cette case d&eacute;marre Tiny-&eacute;diteurs dans un &eacute;tat d&eacute;sactiv&eacute;. Devrait &ecirc;tre utilis&eacute;e avec la case a cocher &quot;Afficher WYSIWYG Oui/Non&quot;.';
$lang['loadcmslinkertext'] = 'Charger le CMSmslinker&nbsp;';
$lang['loadcmslinkerhelp'] = 'Ceci g&eacute;n&egrave;re le code javascript pour pouvoir ajouter &#039;cmslinker&#039; &agrave; la barre d&#039;outils.';
$lang['cmslinkerstyletext'] = 'Style pour CMS-linker&nbsp;';
$lang['cmsselflinkstyle'] = 'Style - {cms_selflink}';
$lang['ahrefstyle'] = 'Style - <a href>';
$lang['relativeurlstext'] = 'G&eacute;n&eacute;rer les urls relatives&nbsp;';
$lang['forcecleanpastetext'] = 'Forcer le nettoyage en collant&nbsp;';
$lang['forcecleanpastehelp'] = 'Cela peut &ecirc;tre utile pour enlever un formatage &eacute;trange lors du collage avec Word etc...';
$lang['bodycss_text'] = 'Tag CSS pour le &quot;Body&quot; de l&#039;&eacute;diteur&nbsp;';
$lang['bodycss_help'] = 'Laisser en blanc ou indiquer &quot;DEFAULT&quot; pour utiliser les CSS. <br/>Note&nbsp;: Pour avoir le fond de page de l&#039;&eacute;diteur en blanc indiquer&nbsp;: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Inclure seulement le CSS pour l&#039;&eacute;cran&nbsp;';
$lang['includeonlyscreencss_help'] = 'La s&eacute;lection permet de joindre des feuilles de style pour &#039;Media type screen&#039; (l&#039;&eacute;cran) qui seront inclus dans la s&eacute;lection &#039;Styles&#039; de l&#039;&eacute;diteur TinyMCE.';
$lang['usestaticconfigtext'] = 'Utilisez le fichier de configuration statique&nbsp;';
$lang['usestaticconfighelp'] = 'Cela peut aider le fonctionnement de Tiny sur des h&eacute;bergements avec par exemple des statistiques... , cassant le code javascript cr&eacute;&eacute; dans le fichier de configuration';
$lang['usestaticconfigwarning'] = 'Attention ! Vous avez coch&eacute; l&#039;option avec un fichier de configuration statique, mais votre dossier / tmp n&#039;a pas les permissions en &eacute;criture. Cela emp&ecirc;chera le module d&#039;enregistrer le fichier de configuration statique et rendra plus que probablement TinyMCE non op&eacute;rationnel.';
$lang['ignoremodifyfilestext'] = 'Ignorer la &#039;permission de modifier des fichiers&#039; pour FilePicker&nbsp;';
$lang['ignoremodifyfileshelp'] = 'Avertissement : Cela permet des op&eacute;rations sur certains fichiers m&ecirc;me si la &#039;permission de modifier les fichiers&#039; n&#039;est pas d&eacute;fini pour le groupe d&#039;utilisateurs actuels. Cela peut effectivement &ecirc;tre utilis&eacute; conjointement avec la facult&eacute; de limiter l&#039;acc&egrave;s au r&eacute;pertoire utilisateur.';
$lang['showtogglebutton_text'] = 'Montrer la case &agrave; cocher pour afficher l&#039;&eacute;diteur WYSIWYG Oui/Non&nbsp;';
$lang['togglewysiwyg'] = 'Afficher &eacute;diteur WYSIWYG Oui/Non';
$lang['styles_tab'] = 'Styles CSS';
$lang['styles_help'] = 'Si vous laissez le premier champ vide, TinyMCE utilisera votre fichier CSS et listera pour l&#039;utilisateur les styles contenus dans ce fichier.
Si vous voulez seulement certains styles pr&eacute;sent&eacute;s &agrave; l&#039;utilisateur, pr&eacute;ciser dans le formulaire ci-dessous :  &quot;mon_style1=style1; mon_style2=style2&quot;, &quot;style1&quot; &eacute;tant une classe appel&eacute;e dans la feuille de style d&eacute;finie pour le gabarit de la page. Cela se traduira par exemple par < span class=&quot;style1&quot; >text< /span >.';
$lang['css_styles_text'] = 'G&eacute;n&eacute;ral&nbsp;';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. Veuillez v&eacute;rifier vos permissions.';
$lang['error'] = 'Erreur&nbsp;!';
$lang['submit'] = 'Envoyer';
$lang['update'] = 'Mise &agrave; jour';
$lang['savesettings'] = 'Sauvegarder les ajustements';
$lang['settings'] = 'Ajustements';
$lang['settingssaved'] = 'Ajustements sauvegard&eacute;s';
$lang['saveadvanced'] = 'Sauvegarder les ajustements avanc&eacute;s';
$lang['advancedsaved'] = 'Ajustements avanc&eacute;s sauvegard&eacute;s';
$lang['toolbarsaved'] = 'Barre d&#039;outils sauvegard&eacute;e';
$lang['stylessaved'] = 'Styles sauvegard&eacute;s';
$lang['testareatext'] = '<p>Zone de test, aucun contenu ne sera modifi&eacute; avec ceci...</p>';
$lang['reset'] = 'Restaurer par d&eacute;faut';
$lang['resetall'] = 'Restaurer toute la configuration par d&eacute;faut';
$lang['confirmreset'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir restaurer la configuration par d&eacute;faut ?';
$lang['confirmresetall'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir restaurer toute la configuration par d&eacute;faut ?';
$lang['settingsreset'] = 'La configuration par d&eacute;faut est restaur&eacute;e ';
$lang['allsettingsreset'] = 'Toute la configuration par d&eacute;faut est restaur&eacute;e ';
$lang['upgraded'] = 'A &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
$lang['customdropdown'] = 'Dropdown personnalis\351';
$lang['cmsmslinker'] = 'Ins\351rer le lien vers une page cmsms';
$lang['backend_toolbars'] = 'Profil de barre d&#039;outils pour l&#039;administration';
$lang['frontend_toolbars'] = 'Profil de barre d&#039;outils pour le site (Frontend)';
$lang['plugins_tab'] = 'Plugins&nbsp;';
$lang['plugins_help'] = 'Choisir les plugins que vous voulez activer. La documentation est <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">ici</a>';
$lang['plugins_text'] = 'Plugins&nbsp;';
$lang['saveplugins'] = 'Sauvegarder les plugins';
$lang['pluginssaved'] = 'Plugins sauvegard&eacute;s';
$lang['plugins_module'] = 'Plugins du module';
$lang['plugins_common'] = 'Plugins communs';
$lang['module'] = 'Module ';
$lang['description'] = 'Description ';
$lang['plugin'] = 'Plugin ';
$lang['youareintext'] = 'Vous &ecirc;tes dans&nbsp;:&nbsp;';
$lang['loadstylesheettext'] = 'Charger la feuille de style pour le contenu (recommand&eacute;)&nbsp;';
$lang['extrastylestext'] = 'Ajouts &agrave; la feuille de style&nbsp;';
$lang['extrastyleshelp'] = 'Le CSS entr&eacute; ici sera ajout&eacute; &agrave; la feuille de style lue par TinyMCE apr&egrave;s la r&eacute;ception des styles de CMSms ';
$lang['uploadnewfile'] = 'Nouveau fichier&nbsp;';
$lang['uploadfile'] = 'Charger';
$lang['createnewdir'] = 'Nouveau dossier&nbsp;';
$lang['createdir'] = 'Cr&eacute;er';
$lang['nodirname'] = 'Aucun nom de dossier';
$lang['direxists'] = 'Le dossier existe d&eacute;j&agrave;';
$lang['newdircreated'] = 'Nouveau dossier cr&eacute;&eacute; avec succ&egrave;s';
$lang['newdirfailed'] = 'Une erreur est survenue lors de la cr&eacute;ation du dossier';
$lang['nofile'] = 'Aucun fichier charg&eacute;';
$lang['filetoobig'] = 'Le fichier charg&eacute; est trop gros';
$lang['containsillegalchars'] = 'Le nom du fichier contient un ou plusieurs caract&egrave;res non autoris&eacute;s (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Erreur lors du chargement du fichier';
$lang['fileuploaded'] = 'Fichier charg&eacute; avec succ&egrave;s';
$lang['filepickertitle'] = 'Fichiers CMSMadeSimple';
$lang['success'] = 'Succ&egrave;s';
$lang['fileoperations'] = 'Op&eacute;rations sur les fichiers&nbsp;';
$lang['thousanddelimiter'] = '.';
$lang['size'] = 'Taille';
$lang['dimensions'] = 'LargxHaut';
$lang['advanced_tab'] = 'Avanc&eacute;';
$lang['help'] = '	<h3>Que fait ce module&nbsp;?</h3>
	<p>Active TinyMCE pour &ecirc;tre utilis&eacute; en tant que WYSIWYG.</p>
	<h3>Comment l&#039;utiliser?</h3>
	<p>Installez le module, puis allez &agrave; &quot;Mes pr&eacute;f&eacute;rences / Pr&eacute;f&eacute;rences de l&#039;utilisateur&quot; et d&eacute;finissez TinyMCE comme WYSIWYG de votre choix.</p>
<p>Modifier les permissions des groupes afin d&#039;autoriser les pr&eacute;f&eacute;rences pour TinyMCE.</p>

  <h3>Correcteur orthographique</h3>
  <p>Depuis la version 2.6.0, TinyMCE inclut un correcteur orthographique en ligne. S&#039;il vous pla&icirc;t notez que SSL doit &ecirc;tre activ&eacute; dans la configuration de votre serveur pour que cela fonctionne. Sur certaines configurations de cette option peut &ecirc;tre appel&eacute;e php_openssl</p>

<h3>D&eacute;pannage</h3>
	Certaines personnes ont des probl&egrave;mes avec Tiny lors de l&#039;installation ou de la mise &agrave; niveau. Voici une liste de choses &agrave; essayer avant de me contacter pour obtenir une aide suppl&eacute;mentaire.
	<br/>
	<ul>
	<li>1. S&rsquo;il vous pla&icirc;t, s&rsquo;il vous pla&icirc;t, essayez &agrave; nouveau de renvoyer les fichiers du module TinyMCE vers votre serveur. Cela est une chose qui a aid&eacute; de nombreux utilisateurs.</li>
	<li>2. Si vous faites une mise &agrave; jour, essayer de r&eacute;initialiser tous les param&egrave;tres. Pas &eacute;vident si vous avez personnalis&eacute; plusieurs options, je le sais, mais il y a de nombreuses modifications entre les versions 2.3.x &agrave; 2.4.x du module.</li>
	<li>3. Essayez d&#039;activer l&#039;option de configuration statique dans les param&egrave;tres avanc&eacute;s. Cela fonctionne mieux sur certains syst&egrave;mes (bas&eacute;s sur CGI). Notez que cela n&eacute;cessite que le dossier /tmp ait des permissions en &eacute;criture.</li>
	</ul>
	<br/>
<h3> Plugin de d&eacute;veloppement </h3> 
  Depuis la version 2.7.0 du module TinyMCE  donne la possibilit&eacute; d&#039;avoir votre propre plugin TinyMCE l&#039;int&eacute;rieur de vos modules. Une ic&ocirc;ne personnalis&eacute;e vous permettra d&#039;ins&eacute;rer du contenu dans certains modules, comme Gallery etc... Pour cela c&#039;est une affaire assez technique, mais si vous &ecirc;tes un d&eacute;veloppeur int&eacute;ress&eacute; par ce plugin, regardez s&#039;il vous pla&icirc;t dans le dossier TinyMCE/docs pour d&#039;autres instructions.';
$lang['utma'] = '156861353.2003866910.1245652859.1275308886.1276552747.149';
$lang['utmz'] = '156861353.1276552748.149.136.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
$lang['qca'] = '4a3d1b41-5eb36-c9570-f49ea';
$lang['utmb'] = '156861353.1.10.1276552747';
$lang['utmc'] = '156861353';
?>